@@ -8,12 +8,12 @@ from azureml.pipeline.core.graph import PipelineParameter
 from azureml.pipeline.steps import PythonScriptStep
 from azureml.pipeline.core import Pipeline
 
-from luna.lunaUtils import LunaUtils
+from luna.baseLunaUtils import BaseLunaUtils
 
 import os
 import yaml
 
-class AzureMLLunaUtils(LunaUtils):
+class AzureMLLunaUtils(BaseLunaUtils):
 
     def GetAMLWorkspace(self):
         try:
